==> jc-1.4.0.tar.gz: soot/shimple/AbstractShimpleExprSwitch.h <==
// public abstract class soot.shimple.AbstractShimpleExprSwitch

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class f2955654a9a2118a soot_jimple_AbstractExprSwitch
// @dep_class c1531341497e36fb soot_shimple_AbstractShimpleExprSwitch

// header file dependencies
// @dep_header soot_jimple_AbstractExprSwitch

#include "soot/jimple/AbstractExprSwitch.h"

#ifndef _JC_soot_shimple_AbstractShimpleExprSwitch_H_
#define _JC_soot_shimple_AbstractShimpleExprSwitch_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_shimple_PhiExpr$object;

// Typedefs
typedef struct _jc_soot_shimple_AbstractShimpleExprSwitch$sub_refs	_jc_soot_shimple_AbstractShimpleExprSwitch$sub_refs;
typedef struct _jc_soot_shimple_AbstractShimpleExprSwitch$sub_nonrefs	_jc_soot_shimple_AbstractShimpleExprSwitch$sub_nonrefs;
typedef struct _jc_soot_shimple_AbstractShimpleExprSwitch$refs	_jc_soot_shimple_AbstractShimpleExprSwitch$refs;
typedef struct _jc_soot_shimple_AbstractShimpleExprSwitch$nonrefs	_jc_soot_shimple_AbstractShimpleExprSwitch$nonrefs;
typedef struct _jc_soot_shimple_AbstractShimpleExprSwitch$object	_jc_soot_shimple_AbstractShimpleExprSwitch$object;

typedef const struct _jc_soot_shimple_AbstractShimpleExprSwitch$vmethods	_jc_soot_shimple_AbstractShimpleExprSwitch$vmethods;
typedef const struct _jc_soot_shimple_AbstractShimpleExprSwitch$vtable	_jc_soot_shimple_AbstractShimpleExprSwitch$vtable;
typedef const struct _jc_soot_shimple_AbstractShimpleExprSwitch$vtype	_jc_soot_shimple_AbstractShimpleExprSwitch$vtype;

// Constructors
extern void _jc_soot_shimple_AbstractShimpleExprSwitch$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_shimple_AbstractShimpleExprSwitch$object *);

// Virtual methods
extern void _jc_soot_shimple_AbstractShimpleExprSwitch$method$casePhiExpr$c285db4a50a108e9(_jc_env *, struct _jc_soot_shimple_AbstractShimpleExprSwitch$object *, struct _jc_object *);

// Virtual method descriptors
extern _jc_method _jc_soot_shimple_AbstractShimpleExprSwitch$method_info$casePhiExpr$c285db4a50a108e9;

// Virtual methods structure
struct _jc_soot_shimple_AbstractShimpleExprSwitch$vmethods {
	void	(*casePhiExpr$c285db4a50a108e9)(_jc_env *, struct _jc_soot_shimple_AbstractShimpleExprSwitch$object *, struct _jc_object *);
};

// Vtable
struct _jc_soot_shimple_AbstractShimpleExprSwitch$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_AbstractExprSwitch$vmethods	soot_jimple_AbstractExprSwitch;
	_jc_soot_shimple_AbstractShimpleExprSwitch$vmethods	soot_shimple_AbstractShimpleExprSwitch;
};

// Vtype
struct _jc_soot_shimple_AbstractShimpleExprSwitch$vtype {
	_jc_type			type;
	_jc_soot_shimple_AbstractShimpleExprSwitch$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_shimple_AbstractShimpleExprSwitch$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_shimple_AbstractShimpleExprSwitch$refs {
    _jc_soot_shimple_AbstractShimpleExprSwitch$sub_refs	soot_shimple_AbstractShimpleExprSwitch;
    _jc_soot_jimple_AbstractExprSwitch$sub_refs	soot_jimple_AbstractExprSwitch;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_shimple_AbstractShimpleExprSwitch$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_shimple_AbstractShimpleExprSwitch$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_AbstractExprSwitch$sub_nonrefs	soot_jimple_AbstractExprSwitch;
    _jc_soot_shimple_AbstractShimpleExprSwitch$sub_nonrefs	soot_shimple_AbstractShimpleExprSwitch;
};

// Object instance structure
struct _jc_soot_shimple_AbstractShimpleExprSwitch$object {
	_jc_soot_shimple_AbstractShimpleExprSwitch$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_shimple_AbstractShimpleExprSwitch$vtype	*vtype;
	_jc_soot_shimple_AbstractShimpleExprSwitch$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_shimple_AbstractShimpleExprSwitch$vtype _jc_soot_shimple_AbstractShimpleExprSwitch$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_shimple_AbstractShimpleExprSwitch, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_shimple_AbstractShimpleExprSwitch$class_object;

#endif	/* _JC_soot_shimple_AbstractShimpleExprSwitch_H_ */

==> jc-1.4.6.tar.gz: soot/shimple/AbstractShimpleExprSwitch.h <==
// public abstract class soot.shimple.AbstractShimpleExprSwitch

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class f2955654a9a2118a soot_jimple_AbstractExprSwitch
// @dep_class c1531341497e36fb soot_shimple_AbstractShimpleExprSwitch

// header file dependencies
// @dep_header soot_jimple_AbstractExprSwitch

#include "soot/jimple/AbstractExprSwitch.h"

#ifndef _JC_soot_shimple_AbstractShimpleExprSwitch_H_
#define _JC_soot_shimple_AbstractShimpleExprSwitch_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_shimple_PhiExpr$object;

// Typedefs
typedef struct _jc_soot_shimple_AbstractShimpleExprSwitch$sub_refs	_jc_soot_shimple_AbstractShimpleExprSwitch$sub_refs;
typedef struct _jc_soot_shimple_AbstractShimpleExprSwitch$sub_nonrefs	_jc_soot_shimple_AbstractShimpleExprSwitch$sub_nonrefs;
typedef struct _jc_soot_shimple_AbstractShimpleExprSwitch$refs	_jc_soot_shimple_AbstractShimpleExprSwitch$refs;
typedef struct _jc_soot_shimple_AbstractShimpleExprSwitch$nonrefs	_jc_soot_shimple_AbstractShimpleExprSwitch$nonrefs;
typedef struct _jc_soot_shimple_AbstractShimpleExprSwitch$object	_jc_soot_shimple_AbstractShimpleExprSwitch$object;

typedef const struct _jc_soot_shimple_AbstractShimpleExprSwitch$vmethods	_jc_soot_shimple_AbstractShimpleExprSwitch$vmethods;
typedef const struct _jc_soot_shimple_AbstractShimpleExprSwitch$vtable	_jc_soot_shimple_AbstractShimpleExprSwitch$vtable;
typedef const struct _jc_soot_shimple_AbstractShimpleExprSwitch$vtype	_jc_soot_shimple_AbstractShimpleExprSwitch$vtype;

// Constructors
extern void _jc_soot_shimple_AbstractShimpleExprSwitch$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_shimple_AbstractShimpleExprSwitch$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_shimple_AbstractShimpleExprSwitch$method$casePhiExpr$c285db4a50a108e9(_jc_env *, struct _jc_soot_shimple_AbstractShimpleExprSwitch$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_shimple_AbstractShimpleExprSwitch$method_info$casePhiExpr$c285db4a50a108e9;

// Virtual methods structure
struct _jc_soot_shimple_AbstractShimpleExprSwitch$vmethods {
	void	(*casePhiExpr$c285db4a50a108e9)(_jc_env *, struct _jc_soot_shimple_AbstractShimpleExprSwitch$object *, struct _jc_object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_shimple_AbstractShimpleExprSwitch$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_AbstractExprSwitch$vmethods	soot_jimple_AbstractExprSwitch;
	_jc_soot_shimple_AbstractShimpleExprSwitch$vmethods	soot_shimple_AbstractShimpleExprSwitch;
};

// Vtype
struct _jc_soot_shimple_AbstractShimpleExprSwitch$vtype {
	_jc_type			type;
	_jc_soot_shimple_AbstractShimpleExprSwitch$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_shimple_AbstractShimpleExprSwitch$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_shimple_AbstractShimpleExprSwitch$refs {
    _jc_soot_shimple_AbstractShimpleExprSwitch$sub_refs	soot_shimple_AbstractShimpleExprSwitch;
    _jc_soot_jimple_AbstractExprSwitch$sub_refs	soot_jimple_AbstractExprSwitch;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_shimple_AbstractShimpleExprSwitch$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_shimple_AbstractShimpleExprSwitch$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_AbstractExprSwitch$sub_nonrefs	soot_jimple_AbstractExprSwitch;
    _jc_soot_shimple_AbstractShimpleExprSwitch$sub_nonrefs	soot_shimple_AbstractShimpleExprSwitch;
};

// Object instance structure
struct _jc_soot_shimple_AbstractShimpleExprSwitch$object {
	_jc_soot_shimple_AbstractShimpleExprSwitch$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_shimple_AbstractShimpleExprSwitch$vtype	*vtype;
	_jc_soot_shimple_AbstractShimpleExprSwitch$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_shimple_AbstractShimpleExprSwitch$vtype _jc_soot_shimple_AbstractShimpleExprSwitch$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_shimple_AbstractShimpleExprSwitch, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_shimple_AbstractShimpleExprSwitch$class_object;

#endif	/* _JC_soot_shimple_AbstractShimpleExprSwitch_H_ */
